@@ -3,6 +3,8 @@ package org.gcube.portlets.widgets.ckandatapublisherwidget.server;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Calendar;
+import java.util.Collections;
+import java.util.Comparator;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -15,21 +17,22 @@ import javax.servlet.http.HttpSession;
 import org.gcube.datacatalogue.ckanutillibrary.server.DataCatalogue;
 import org.gcube.datacatalogue.ckanutillibrary.server.DataCatalogueFactory;
 import org.gcube.datacatalogue.ckanutillibrary.server.utils.SessionCatalogueAttributes;
-import org.gcube.datacatalogue.ckanutillibrary.server.utils.UtilMethods;
+import org.gcube.datacatalogue.ckanutillibrary.server.utils.CatalogueUtilMethods;
 import org.gcube.datacatalogue.ckanutillibrary.shared.ResourceBean;
 import org.gcube.datacatalogue.ckanutillibrary.shared.RolesCkanGroupOrOrg;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.client.CKanPublisherService;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.server.threads.AssociationToGroupAndNotifyThread;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.server.threads.WritePostCatalogueManagerThread;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.server.utils.CatalogueRoleManager;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.server.utils.DiscoverTagsList;
-import org.gcube.portlets.widgets.ckandatapublisherwidget.server.utils.Utils;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.server.utils.GenericUtils;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.server.utils.MetadataDiscovery;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.server.utils.WorkspaceUtils;
-import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.DatasetMetadataBean;
-import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.GroupBean;
-import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.LicensesBean;
-import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.MetaDataProfileBean;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.DatasetBean;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.OrganizationBean;
 import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.ResourceElementBean;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.licenses.LicenseBean;
+import org.gcube.portlets.widgets.ckandatapublisherwidget.shared.metadata.MetaDataProfileBean;
 import org.gcube.vomanagement.usermanagement.GroupManager;
 import org.gcube.vomanagement.usermanagement.UserManager;
 import org.gcube.vomanagement.usermanagement.exception.GroupRetrievalFault;
@@ -37,7 +40,9 @@ import org.gcube.vomanagement.usermanagement.exception.UserManagementSystemExcep
 import org.gcube.vomanagement.usermanagement.impl.LiferayGroupManager;
 import org.gcube.vomanagement.usermanagement.impl.LiferayUserManager;
 import org.gcube.vomanagement.usermanagement.model.GCubeUser;
+import org.geojson.GeoJsonObject;
 
+import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.gwt.user.server.rpc.RemoteServiceServlet;
 import com.liferay.portal.kernel.log.Log;
 import com.liferay.portal.kernel.log.LogFactoryUtil;
@@ -58,6 +63,8 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 	//private static final org.slf4j.Logger logger = LoggerFactory.getLogger(CKANPublisherServicesImpl.class);
 	private static final Log logger = LogFactoryUtil.getLog(CKANPublisherServicesImpl.class);
 	private static final String ITEM_URL_FIELD = "Item URL";
+	private static final String SYS_TYPE = "system:type";
+	private static final String TAGS_VOCABULARY_KEY = "TAGS_VOCABULARY";
 
 	// map <orgName, scope>
 	private ConcurrentHashMap<String, String> mapOrganizationScope = new ConcurrentHashMap<String, String>();
@@ -72,7 +79,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 		DataCatalogue instance = null;
 		String scopeInWhichDiscover = null;
 		try{
-			scopeInWhichDiscover = (scope != null && !scope.isEmpty()) ? scope : Utils.getCurrentContext(getThreadLocalRequest(), false);
+			scopeInWhichDiscover = (scope != null && !scope.isEmpty()) ? scope : GenericUtils.getCurrentContext(getThreadLocalRequest(), false);
 			logger.debug("Discovering ckan instance into scope " + scopeInWhichDiscover);
 			instance = DataCatalogueFactory.getFactory().getUtilsPerScope(scopeInWhichDiscover);
 		}catch(Exception e){
@@ -94,14 +101,14 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 		List<OrganizationBean> orgsName = new ArrayList<OrganizationBean>();
 
 		HttpSession httpSession = getThreadLocalRequest().getSession();
-		String keyPerScope = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_ORGANIZATIONS_PUBLISH_KEY, scope);
+		String keyPerScope = CatalogueUtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_ORGANIZATIONS_PUBLISH_KEY, scope);
 
 		if(httpSession.getAttribute(keyPerScope) != null){
 			orgsName = (List<OrganizationBean>)httpSession.getAttribute(keyPerScope);
 			logger.info("List of organizations was into session " + orgsName);
 		}
 		else{
-			Utils.getHighestRole(scope, username, Utils.getGroupFromScope(scope).getGroupName(), this, orgsName);
+			CatalogueRoleManager.getHighestRole(scope, username, GenericUtils.getGroupFromScope(scope).getGroupName(), this, orgsName);
 			httpSession.setAttribute(keyPerScope, orgsName);
 			logger.info("Organizations name for user " + username + " has been saved into session " + orgsName);
 		}
@@ -132,55 +139,57 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 	private String findLicenseIdByLicense(String chosenLicense) {	
 
 		// get scope from client url
-		String scope = Utils.getScopeFromClientUrl(getThreadLocalRequest());
+		String scope = GenericUtils.getScopeFromClientUrl(getThreadLocalRequest());
 		return getCatalogue(scope).findLicenseIdByLicenseTitle(chosenLicense);
 
 	}
 
 	@Override
-	public LicensesBean getLicenses() {
+	public List<LicenseBean> getLicenses() {
 
 		// get http session
 		HttpSession httpSession = getThreadLocalRequest().getSession();
-		String scope = Utils.getScopeFromClientUrl(getThreadLocalRequest());
+		String scope = GenericUtils.getScopeFromClientUrl(getThreadLocalRequest());
 		logger.info("Request for CKAN licenses for scope " + scope);
-		String keyPerScope = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_LICENSES_KEY, scope);
+		String keyPerScope = CatalogueUtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_LICENSES_KEY, scope);
 
-		LicensesBean licensesBean = null;
+		List<LicenseBean> licensesBean = null;
 		if(httpSession.getAttribute(keyPerScope) != null){
-			licensesBean = (LicensesBean)httpSession.getAttribute(keyPerScope);
+			licensesBean = (List<LicenseBean>)httpSession.getAttribute(keyPerScope);
 			logger.info("List of licenses was into session");
 		}
 		else{
-			List<CkanLicense> titlesLicenses = getCatalogue(scope).getLicenses();
-			List<String> titles = new ArrayList<String>();
-			List<String> urls = new ArrayList<String>();
-			for (CkanLicense license : titlesLicenses) {
-				titles.add(license.getTitle());
-				String url = (license.getUrl() != null && !license.getUrl().isEmpty()) ? license.getUrl() : "";
-				urls.add(url);
+			List<CkanLicense> licenses = getCatalogue(scope).getLicenses();
+			licensesBean = new ArrayList<LicenseBean>();
+			for (CkanLicense license : licenses) {
+				licensesBean.add(new LicenseBean(license.getTitle(), license.getUrl()));
 			}
-			licensesBean = new LicensesBean(titles, urls);
+
+			// sort the list
+			Collections.sort(licensesBean, new Comparator<LicenseBean>(){
+				public int compare(LicenseBean l1, LicenseBean l2){
+					return l1.getTitle().compareTo(l2.getTitle());
+				}});
+
 			httpSession.setAttribute(keyPerScope, licensesBean);
 			logger.info("List of licenses has been saved into session");
 		}
 
 		return licensesBean;
-
 	}
 
 	@Override
-	public DatasetMetadataBean getDatasetBean(String folderId){
+	public DatasetBean getDatasetBean(String folderId) throws Exception{
 
-		DatasetMetadataBean bean = null;
-		String userName = Utils.getCurrentUser(getThreadLocalRequest()).getUsername();
+		DatasetBean bean = null;
+		String userName = GenericUtils.getCurrentUser(getThreadLocalRequest()).getUsername();
 
 		logger.info("DatasetBean request for " + folderId + " and " + userName);
 
 		if(isWithinPortal()){
 			try{
 
-				String scope = Utils.getScopeFromClientUrl(getThreadLocalRequest());
+				String scope = GenericUtils.getScopeFromClientUrl(getThreadLocalRequest());
 
 				logger.debug("Scope recovered from session is " + scope);
 
@@ -192,7 +201,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 
 				// build bean
 				logger.debug("Building bean");
-				bean = new DatasetMetadataBean();
+				bean = new DatasetBean();
 
 				bean.setId(folderId);
 				bean.setOwnerIdentifier(userName);
@@ -211,15 +220,16 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 				}
 
 			}catch(Exception e){
-				logger.error("Error while retrieving folder information", e);
+				logger.error("Error while retrieving bean information", e);
+				throw new Exception("Error while retrieving basic information " + e.getMessage());
 			}
 		}else{
 
 			logger.info("DEV MODE DETECTED");
-			Utils.getCurrentToken(getThreadLocalRequest(), true);
+			GenericUtils.getCurrentToken(getThreadLocalRequest(), true);
 
 			try{
-				bean = new DatasetMetadataBean();
+				bean = new DatasetBean();
 				bean.setId(folderId);
 				bean.setDescription("This is a fantastic description");
 				bean.setVersion(1);
@@ -230,8 +240,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 				bean.setAuthorEmail("costantino.perciante@isti.cnr.it");
 				bean.setMaintainer("Costantino Perciante");
 				bean.setMaintainerEmail("costantino.perciante@isti.cnr.it");
-				//bean.setOrganizationList(getUserOrganizationsListAdmin(userName, Utils.getCurrentContext(getThreadLocalRequest(), true)));
-				bean.setOrganizationList(Arrays.asList(new OrganizationBean("preVRE", "prevre")));
+				bean.setOrganizationList(Arrays.asList(new OrganizationBean("NextNext", "nextnext", true)));
 				bean.setOwnerIdentifier(userName);
 
 				if(folderId != null && !folderId.isEmpty()){
@@ -239,6 +248,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 				}
 			}catch(Exception e){
 				logger.error("Error while building bean into dev mode", e);
+				throw new Exception("Error while retrieving basic information " + e.getMessage());
 			}
 		}
 
@@ -249,16 +259,18 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 	/**
 	 * Discover from the IS the vocabulary of tags for this scope, if present
 	 * @return a list of tags vocabulary
+	 * @throws Exception 
 	 */
-	private List<String> discoverTagsVocabulary(String context) {
+	private List<String> discoverTagsVocabulary(String context){
 
 		logger.debug("Looking for vocabulary of tags in this context " + context);
-		String keyPerVocabulary = UtilMethods.concatenateSessionKeyScope("TAGS_VOCABULARY", context); // TODO REMOVE
+		String keyPerVocabulary = CatalogueUtilMethods.concatenateSessionKeyScope(TAGS_VOCABULARY_KEY, context); 
 
 		List<String> vocabulary = (List<String>) getThreadLocalRequest().getSession().getAttribute(keyPerVocabulary);
 		if(vocabulary == null){
-			vocabulary = new DiscoverTagsList(context).getTagsVocabulary();
-			getThreadLocalRequest().getSession().setAttribute(keyPerVocabulary, vocabulary);
+			vocabulary = DiscoverTagsList.discoverTagsList(context);
+			if(vocabulary != null)
+				getThreadLocalRequest().getSession().setAttribute(keyPerVocabulary, vocabulary);
 		}
 
 		logger.debug("Vocabulary for tags is " + vocabulary);
@@ -267,13 +279,16 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 	}
 
 	@Override
-	public DatasetMetadataBean createCKanDataset(DatasetMetadataBean toCreate) throws Exception{
+	public List<String> getTagsForOrganization(String orgName) throws Exception{
+		return discoverTagsVocabulary(getScopeFromOrgName(orgName));
+	}
+
+	@Override
+	public DatasetBean createCKanDataset(DatasetBean toCreate) throws Exception{
 
 		try{
-			logger.debug("Request for creating a dataset with these information " + toCreate);
-
-			String userName = Utils.getCurrentUser(getThreadLocalRequest()).getUsername();
-
+			logger.info("Request for creating a dataset with these information " + toCreate);
+			String userName = GenericUtils.getCurrentUser(getThreadLocalRequest()).getUsername();
 			String title = toCreate.getTitle();
 			String organizationNameOrId = toCreate.getSelectedOrganization();
 			String author = toCreate.getAuthorFullName();
@@ -289,7 +304,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 
 			// add Type for custom fields
 			if(toCreate.getChosenType() != null)
-				customFields.put("system:type", Arrays.asList(toCreate.getChosenType()));
+				customFields.put(SYS_TYPE, Arrays.asList(toCreate.getChosenType()));
 
 			boolean setPublic = toCreate.getVisibility();
 
@@ -323,7 +338,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 				// add also this information as custom field
 				Map<String, List<String>> addField = new HashMap<String, List<String>>();
 				addField.put(ITEM_URL_FIELD, Arrays.asList(datasetUrl));
-				utils.patchProductCustomFields(datasetId, userApiKey, addField);
+				utils.patchProductCustomFields(datasetId, userApiKey, addField, false);
 
 				// start a thread that will associate this dataset with the group
 				if(/*toCreate.getChosenType() != null ||*/ toCreate.getGroups() != null){
@@ -331,11 +346,12 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 					AssociationToGroupAndNotifyThread threadAssociationToGroup = 
 							new AssociationToGroupAndNotifyThread(
 									toCreate.getGroups(),
+									toCreate.getGroupsForceCreation(),
 									null, //toCreate.getChosenType(), TODO
 									datasetUrl,
 									datasetId,
 									toCreate.getTitle(),
-									Utils.getCurrentUser(getThreadLocalRequest()).getFullname(),
+									GenericUtils.getCurrentUser(getThreadLocalRequest()).getFullname(),
 									userName, 
 									utils, 
 									organizationNameOrId,
@@ -354,7 +370,8 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 								datasetUrl, 
 								false, // send notification to other people 
 								toCreate.getTags(), 
-								Utils.getCurrentUser(getThreadLocalRequest()).getFullname()
+								GenericUtils.getCurrentUser(getThreadLocalRequest()).getFullname(),
+								GenericUtils.getCurrentClientUrl(getThreadLocalRequest())
 								);
 				threadWritePost.start();
 
@@ -365,15 +382,16 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 
 		}catch(Exception e){
 			logger.error("Error while creating item ", e);
-			throw new Exception(e.getMessage());
+			throw new Exception("An error occurred while creating the item " + e.getMessage());
 		}
 
 		return null;
+
 	}
 
 	@Override
 	public ResourceElementBean addResourceToDataset(ResourceElementBean resource, String datasetId) throws Exception{
-		String username = Utils.getCurrentUser(getThreadLocalRequest()).getUsername();
+		String username = GenericUtils.getCurrentUser(getThreadLocalRequest()).getUsername();
 
 		logger.debug("Incoming request for creating new resource for dataset with id " + datasetId + " and organization name of the dataset is " + resource.getOrganizationNameDatasetParent());
 		logger.debug("Owner is " + username + " and resource is " + resource);
@@ -413,7 +431,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 	}
 
 	@Override
-	public boolean deleteResourceFromDataset(ResourceElementBean resource) {
+	public boolean deleteResourceFromDataset(ResourceElementBean resource) throws Exception{
 
 		logger.debug("Request for deleting resource " + resource);
 		boolean deleted = false;
@@ -423,7 +441,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 			return deleted;
 		}else{
 
-			String username = Utils.getCurrentUser(getThreadLocalRequest()).getUsername();
+			String username = GenericUtils.getCurrentUser(getThreadLocalRequest()).getUsername();
 			try{
 				// get the scope in which we should discover the ckan instance given the organization name in which the dataset was created
 				String scope = getScopeFromOrgName(resource.getOrganizationNameDatasetParent());
@@ -436,41 +454,42 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 					logger.error("Resource described by " + resource + " NOT deleted");
 			}catch(Exception e){
 				logger.error("Error while trying to delete resource described by " + resource, e);
+				throw new Exception("Error while trying to delete resource." + e.getMessage());
 			}
 			return deleted;
-
 		}
 	}
 
 	@Override
-	public List<MetaDataProfileBean> getProfiles(String orgName) {
+	public List<MetaDataProfileBean> getProfiles(String orgName) throws Exception{
 
 		logger.debug("Requested profiles for products into orgName " + orgName);
 		List<MetaDataProfileBean> toReturn = new ArrayList<MetaDataProfileBean>();
 		try{
 			String evaluatedScope = getScopeFromOrgName(orgName);
 			logger.debug("Evaluated scope is  " + evaluatedScope);
-			toReturn = Utils.getMetadataProfilesList(evaluatedScope, getThreadLocalRequest());
+			toReturn = MetadataDiscovery.getMetadataProfilesList(evaluatedScope, getThreadLocalRequest());
 		}catch(Exception e){
 			logger.error("Failed to retrieve profiles for scope coming from organization name " + orgName, e);
+			throw e;
 		}
 
 		return toReturn;
 	}
 
 	@Override
-	public boolean datasetIdAlreadyExists(String title) {
-
+	public boolean datasetIdAlreadyExists(String title, String orgName) throws Exception{
 		if(title == null || title.isEmpty())
 			return true; // it's an error somehow
 		try{
-			String scope = Utils.getScopeFromClientUrl(getThreadLocalRequest());
-			String idFromTitle = UtilMethods.fromProductTitleToName(title);
-			return getCatalogue(scope).existProductWithNameOrId(idFromTitle);
+			String scopeFromOrgName = getScopeFromOrgName(orgName);
+			String idFromTitle = CatalogueUtilMethods.fromProductTitleToName(title);
+			logger.debug("Evaluating if dataset with id " + title + " in context " + scopeFromOrgName + " already exists");
+			return getCatalogue(scopeFromOrgName).existProductWithNameOrId(idFromTitle);
 		}catch(Exception e){
 			logger.error("Unable to check if such a dataset id already exists", e);
+			throw new Exception("Unable to check if such a dataset id already exists " + e.getMessage());
 		}
-		return false;
 	}
 
 	/**
@@ -490,7 +509,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 				toReturn = mapOrganizationScope.get(orgName);
 			else{
 				try{
-					String evaluatedScope = Utils.retrieveScopeFromOrganizationName(orgName);
+					String evaluatedScope = GenericUtils.retrieveScopeFromOrganizationName(orgName);
 					mapOrganizationScope.put(orgName, evaluatedScope);
 					toReturn = evaluatedScope;
 				}catch(Exception e){
@@ -498,7 +517,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 				}
 			}
 		}else{
-			toReturn = "/gcube/preprod/preVRE";
+			toReturn = "/gcube/devNext/NextNext";
 			mapOrganizationScope.put(orgName, toReturn);
 		}
 		logger.debug("Returning scope " + toReturn);
@@ -506,24 +525,24 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 	}
 
 	@Override
-	public List<GroupBean> getUserGroups(String orgName) {
+	public List<OrganizationBean> getUserGroups(String orgName) {
 
-		List<GroupBean> toReturn = new ArrayList<GroupBean>();
+		List<OrganizationBean> toReturn = new ArrayList<OrganizationBean>();
 
 		if(isWithinPortal()){
-			String username = Utils.getCurrentUser(getThreadLocalRequest()).getUsername();
+			String username = GenericUtils.getCurrentUser(getThreadLocalRequest()).getUsername();
 
 			logger.debug("Request for user " + username + " groups. Organization name is "  + orgName);
 
 			// get http session
 			HttpSession httpSession = getThreadLocalRequest().getSession();
-			String scope =  orgName != null ? getScopeFromOrgName(orgName) : Utils.getScopeFromClientUrl(getThreadLocalRequest());
+			String scope =  orgName != null ? getScopeFromOrgName(orgName) : GenericUtils.getScopeFromClientUrl(getThreadLocalRequest());
 
 			// check if they are in session
-			String keyPerScopeGroups = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_GROUPS_MEMBER, scope);
+			String keyPerScopeGroups = CatalogueUtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_GROUPS_MEMBER, scope);
 
 			if(httpSession.getAttribute(keyPerScopeGroups) != null){
-				toReturn = (List<GroupBean>)httpSession.getAttribute(keyPerScopeGroups);
+				toReturn = (List<OrganizationBean>)httpSession.getAttribute(keyPerScopeGroups);
 				logger.info("Found user's groups in session " + toReturn);
 			}else{
 
@@ -534,7 +553,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 				for (Entry<String, Map<CkanGroup, RolesCkanGroupOrOrg>> entry : set) {
 					Set<Entry<CkanGroup, RolesCkanGroupOrOrg>> subSet = entry.getValue().entrySet();
 					for (Entry<CkanGroup, RolesCkanGroupOrOrg> subEntry : subSet) {
-						toReturn.add(new GroupBean(subEntry.getKey().getTitle(), subEntry.getKey().getName()));	
+						toReturn.add(new OrganizationBean(subEntry.getKey().getTitle(), subEntry.getKey().getName(), false));	
 					}
 				}
 				httpSession.setAttribute(keyPerScopeGroups, toReturn);
@@ -548,9 +567,9 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 
 
 	@Override
-	public boolean isPublisherUser(boolean isWorkspaceRequest) {
+	public boolean isPublisherUser(boolean isWorkspaceRequest) throws Exception{
 
-		String username = Utils.getCurrentUser(getThreadLocalRequest()).getUsername();
+		String username = GenericUtils.getCurrentUser(getThreadLocalRequest()).getUsername();
 		logger.info("Checking if the user " + username + " can publish or not on the catalogue");
 
 		if(!isWithinPortal()){
@@ -563,12 +582,12 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 			HttpSession httpSession = this.getThreadLocalRequest().getSession();
 
 			// retrieve scope per current portlet url
-			String scopePerCurrentUrl = Utils.getScopeFromClientUrl(getThreadLocalRequest());
+			String scopePerCurrentUrl = GenericUtils.getScopeFromClientUrl(getThreadLocalRequest());
 
 			// get key per scope
-			String keyPerScopeRole = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_HIGHEST_ROLE, scopePerCurrentUrl);
-			String keyPerScopeOrganizations = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_ORGANIZATIONS_PUBLISH_KEY, scopePerCurrentUrl);
-			String keyPerScopeGroups = UtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_GROUPS_MEMBER, scopePerCurrentUrl);
+			String keyPerScopeRole = CatalogueUtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_HIGHEST_ROLE, scopePerCurrentUrl);
+			String keyPerScopeOrganizations = CatalogueUtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_ORGANIZATIONS_PUBLISH_KEY, scopePerCurrentUrl);
+			String keyPerScopeGroups = CatalogueUtilMethods.concatenateSessionKeyScope(SessionCatalogueAttributes.CKAN_GROUPS_MEMBER, scopePerCurrentUrl);
 
 			// check if this information was already into session(true means the user has at least in one org
 			// the role editor), false that he is just a member so he cannot publish
@@ -586,7 +605,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 
 					// we build up also a list that keeps track of the scopes (orgs) in which the user has role ADMIN/EDITOR
 					List<OrganizationBean> orgsInWhichAtLeastEditorRole = new ArrayList<OrganizationBean>();
-					role = Utils.getHighestRole(scopePerCurrentUrl, username, groupName, this, orgsInWhichAtLeastEditorRole);
+					role = CatalogueRoleManager.getHighestRole(scopePerCurrentUrl, username, groupName, this, orgsInWhichAtLeastEditorRole);
 
 					// if he is an admin/editor preload:
 					// 1) organizations in which he can publish (the widget will find these info in session)
@@ -609,10 +628,18 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 
 		}catch(Exception e){
 			logger.error("Failed to check the user's role", e);
+			throw new Exception("Failed to check if you are an Administrator or Editor " + e.getMessage());
 		}
+	}
 
-		// return false
-		return false;
+	@Override
+	public boolean isGeoJSONValid(String geoJson) throws Exception {
+		try{
+			new ObjectMapper().readValue(geoJson, GeoJsonObject.class);
+			return true;
+		}catch(Exception e){
+			throw new Exception("GeoJSON field with value '" + geoJson + "' seems not valid!");
+		}
 	}
 
 }
\ No newline at end of file
